package com.example.catchTheLetters.service;

import com.example.catchTheLetters.entity.VersionDownload;
import com.example.catchTheLetters.utils.R;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * 版本服务接口
 *
 * @author spyn
 */
public interface VersionService {
    /**
     * 获取某个表的版本号(用于Realm对MongoDB的数据表版本进行同步检测，版本号不同则进行同步)
     *
     * @param tableName 表名
     * @return 版本号
     */
    Long getVersion(String tableName);

    /**
     * 设置某个表的版本号(用于Realm对MongoDB的数据表版本进行同步检测，版本号不同则进行同步)
     *
     * @param tableName 表名
     * @param version   版本号
     */
    void setVersion(String tableName, Long version);

    /**
     * 添加下载文件版本
     * @param time 时间
     * @param version 版本号
     * @param url 地址
     */
    R<String> addVersionDownload(Long time, String version, String url, MultipartFile file);

    /**
     * 获取最新的5个版本
     * @return 版本集合
     */
    R<List<VersionDownload>> getNewDownloads();

    String testMinIO(MultipartFile file) throws Exception;
}
